@@ -4,8 +4,10 @@
 function startFarabi(editorId) {
 
 	// Cache dialog jQuery references for later use
-	var $help_search_dialog = $("#help_search_dialog");
-	var $perl_critic_dialog = $("#perl_critic_dialog");
+	var $help_results_dialog = $('#help_results_dialog');
+	var $perl_critic_dialog = $('#perl_critic_dialog');
+	var $about_dialog = $('#about_dialog');
+	var $help_dialog = $("#help_dialog");
 
 	$("#theme_selector").change(function() {
 		var $selectedTheme = $(":selected", this);
@@ -32,28 +34,28 @@ function startFarabi(editorId) {
 		$.post('/help_search', {"topic": topic}, function(results) {
 			if(results.length > 0) {
 				humane.log("Found " + results.length + " help results for '" + topic +"'!");
-				$(".topic", $help_search_dialog).val(topic);
+				$(".topic", $help_results_dialog).val(topic);
 				var html = '';
 				for(var i = 0; i < results.length; i++) {
 					html += '<option value="' + i + '">' + results[i].podname + "  (" + results[i].context + ")" +'</option>';
 				}
 
-				$(".results", $help_search_dialog)
+				$(".results", $help_results_dialog)
 					.html(html)
 					.change(function() {
 						var index = $(':selected', this).val();
-						$(".preview", $help_search_dialog).html(results[index].html);
+						$(".preview", $help_results_dialog).html(results[index].html);
 					}).change().show();
 			} else {
 				humane.log("No help found for '" + topic + "'");
 
-				$(".topic", $help_search_dialog).val(topic);
-				$(".results", $help_search_dialog).html('').hide();
-				$(".preview", $help_search_dialog).html('<span class="text-error">No results found!</span>');
+				$(".topic", $help_results_dialog).val(topic);
+				$(".results", $help_results_dialog).html('').hide();
+				$(".preview", $help_results_dialog).html('<span class="text-error">No results found!</span>');
 			}
 			if(bShowDialog) {
-				$help_search_dialog.modal('show');
-				$(".topic", $help_search_dialog).select().focus();
+				$help_results_dialog.modal('show');
+				$(".topic", $help_results_dialog).select().focus();
 			}
 		});
 	}
@@ -92,6 +94,12 @@ function startFarabi(editorId) {
 		}
 	});
 
+	var podChanged = function(cm) {
+		$.post('/pod2html', {"source": cm.getValue()}, function(html) {
+			$('#pod-tab').html(html);
+		});
+	};
+
 	var editor = CodeMirror.fromTextArea(document.getElementById(editorId), {
 		lineNumbers: true,
 		matchBrackets: true,
@@ -114,6 +122,9 @@ function startFarabi(editorId) {
 
 			// Show editor statistics
 			showEditorStats(cm);
+		},
+		onChange: function(cm) {
+			podChanged(cm);
 		}
 	});
 	// Editor is by default Perl
@@ -125,6 +136,9 @@ function startFarabi(editorId) {
 	// Show editor stats
 	showEditorStats(editor);
 
+	// Update POD tab
+	podChanged(editor);
+
 	// Highlight active line
 	var hlLine = editor.setLineClass(0, "activeline");
 
@@ -171,7 +185,7 @@ function startFarabi(editorId) {
 					html += '<br/><strong>Diagnositcs:</strong><br/>' + violation.diagnostics.replace(/\n/g, '<br/>');
 					html += '<hr/>';
 				}
-				$('.results', $perl_critic_dialog).html(html);
+				$('.modal-body', $perl_critic_dialog).html(html);
 				$perl_critic_dialog.modal("show");
 			} else {
 				humane.log('Your code passed Perl::Critic!');
@@ -179,15 +193,21 @@ function startFarabi(editorId) {
 		});
 	});
 
-	$help_search_dialog.on('hidden', function () {
-		editor.focus();
-	});
-	$perl_critic_dialog.on('hidden', function () {
-		editor.focus();
+	$('.about_button').click(function() {
+		$about_dialog.modal("show");
 	});
 
-	$help_search_dialog.hide();
-	$perl_critic_dialog.hide();
+	$('.help_button').click(function() {
+		$help_dialog.modal("show");
+	});
+
+	var onCloseFocusEditor = function () {
+		editor.focus();
+	};
+	$help_results_dialog.hide().on('hidden', onCloseFocusEditor);
+	$perl_critic_dialog.hide().on('hidden', onCloseFocusEditor);
+	$about_dialog.hide().on('hidden', onCloseFocusEditor);
+	$help_dialog.hide().on('hidden', onCloseFocusEditor);
 
 	$(".topic").typeahead({
 		source : function(query, process) {
@@ -228,7 +248,7 @@ function startFarabi(editorId) {
 function runOnPerlito(source) {
 
 	var $output = $('#output');
-	var $logResult = $("#log-result");
+	var $log = $("#log");
 
 	p5pkg.CORE.print = function(List__) {
 		var i;
@@ -241,7 +261,7 @@ function runOnPerlito(source) {
 		var i;
 		List__.push("\n");
 		for (i = 0; i < List__.length; i++) {
-			$logResult.val( $logResult.val() + p5str(List__[i]));
+			$log.val( $log.val() + p5str(List__[i]));
 		}
 		return true;
 	};
@@ -249,23 +269,23 @@ function runOnPerlito(source) {
 	p5pkg["main"]["Hash_INC"]["Perlito5/strict.pm"] = "Perlito5/strict.pm";
 	p5pkg["main"]["Hash_INC"]["Perlito5/warnings.pm"] = "Perlito5/warnings.pm";
 
-	$logResult.val('');
+	$log.val('');
 	$output.val('');
 	try {
 		// Compile Perl 5 source code into JavaScript
-		$logResult.val($logResult.val() + "Compiling.\n");
+		$log.val($log.val() + "Compiling.\n");
 		var start = new Date().getTime();
 		var js_source = p5pkg["Perlito5"].compile_p5_to_js([source]);
-		$logResult.val($logResult.val() + "Compilation time: " + (new Date().getTime() - start) + "ms\n");
+		$log.val($log.val() + "Compilation time: " + (new Date().getTime() - start) + "ms\n");
 
 		// Run JavaScript inside your browser
 		start = new Date().getTime();
 		eval(js_source);
-		$logResult.val( $logResult.val() + "Running time: " + (new Date().getTime() - start) + "ms\n");
+		$log.val( $log.val() + "Running time: " + (new Date().getTime() - start) + "ms\n");
 		$('a[href="#output-tab"]').tab('show');
 	}
 	catch(err) {
-		$logResult.val("Error:\n" + err + "\nCompilation aborted.\n");
+		$log.val("Error:\n" + err + "\nCompilation aborted.\n");
 		$('a[href="#log-tab"]').tab('show');
 	}
 }
